
from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _

default_app_config = 'leonardo_store_faq.Config'


LEONARDO_APPS = ['leonardo_store_faq']


class Config(AppConfig):
    name = 'leonardo_store_faq'
    verbose_name = _("Store FAQ")



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('catalogue', '0012_product_product_backend_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProductQuestion',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('order', models.IntegerField(null=True, blank=True)),
                ('product', models.ForeignKey(related_name='questions', to='catalogue.Product')),
            ],
            options={
                'verbose_name': 'Product question',
                'verbose_name_plural': 'Product questions',
            },
        ),
        migrations.CreateModel(
            name='Question',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('question_text', models.TextField()),
                ('answer', models.TextField()),
            ],
            options={
                'verbose_name': 'question',
                'verbose_name_plural': 'questions',
            },
        ),
        migrations.AddField(
            model_name='productquestion',
            name='question',
            field=models.ForeignKey(related_name='product_questions', to='leonardo_store_faq.Question'),
        ),
    ]



from django.db import models
from django.utils.encoding import python_2_unicode_compatible, force_text
from django.utils.translation import pgettext_lazy, ugettext_lazy as _


@python_2_unicode_compatible
class Question(models.Model):
    name = models.CharField(
        max_length=255, verbose_name=pgettext_lazy("Inanimate object", "Name"))
    question_text = models.TextField(verbose_name=_("Question text"))
    answer = models.TextField(verbose_name=_("Answer"))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _("question")
        verbose_name_plural = _("questions")


@python_2_unicode_compatible
class ProductQuestion(models.Model):
    question = models.ForeignKey(
        Question, related_name="product_questions", verbose_name=_("Question"))
    product = models.ForeignKey("catalogue.Product", related_name="questions",
                                verbose_name=_("Product"))
    order = models.IntegerField(
        null=True, blank=True, verbose_name=pgettext_lazy("As in ordering", "Order"))

    def __str__(self):
        return " - ".join([force_text(self.question),
                           self.product,
                           self.order])

    class Meta:
        verbose_name = _("Product question")
        verbose_name_plural = _("Product questions")



from django.core.urlresolvers import reverse
from django.http import Http404, HttpResponse, HttpResponseRedirect
from django.shortcuts import get_object_or_404, render
from django.template import loader

from .models import  Question, ProductQuestion


def IndexViews(request):
    latest_question_list = Question.objects.order_by('-pub_date')[:5]
    context = {'latest_question_list': latest_question_list}
    return render(request, 'polls/index.html', context)


def QuestionViews(request, question_id):
    question = get_object_or_404(Question, pk=question_id)
    return render(request, 'polls/detail.html', {'question': question})


def ProductQuestionViews(request, question_id):
    question = get_object_or_404(Question, pk=question_id)
    return render(request, 'polls/results.html', {'question': question})



from django import forms
from django.contrib import admin
from leonardo.widgets import get_htmltext_widget

from .models import Question


class QuestionAdminForm(forms.ModelForm):

    class Meta:
        model = Question
        widgets = {
            'question_text': get_htmltext_widget(),
            'answer': get_htmltext_widget()
        }
        exclude = tuple()


class QuestionAdmin(admin.ModelAdmin):
    form = QuestionAdminForm

    list_display = ('name', )


admin.site.register(Question, QuestionAdmin)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leonardo_store_faq', '0002_question_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='productquestion',
            name='order',
            field=models.IntegerField(null=True, verbose_name='Order', blank=True),
        ),
        migrations.AlterField(
            model_name='productquestion',
            name='product',
            field=models.ForeignKey(related_name='questions', verbose_name='Product', to='catalogue.Product'),
        ),
        migrations.AlterField(
            model_name='productquestion',
            name='question',
            field=models.ForeignKey(related_name='product_questions', verbose_name='Question', to='leonardo_store_faq.Question'),
        ),
        migrations.AlterField(
            model_name='question',
            name='answer',
            field=models.TextField(verbose_name='Answer'),
        ),
        migrations.AlterField(
            model_name='question',
            name='name',
            field=models.CharField(max_length=255, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='question',
            name='question_text',
            field=models.TextField(verbose_name='Question text'),
        ),
    ]
